@@ -49,4 +49,5 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef SANE_MALLOC_PROTOS
-#undef USE_LIBICONV
+#undef USE_LIBICONV_GNU
+#undef USE_LIBICONV_NATIVE
