@@ -1114,7 +1114,8 @@ g_source_set_callback (GSource        *source,
  * @priority: the new priority.
  * 
  * Sets the priority of a source. While the main loop is being
- * run, a source will 
+ * run, a source will be dispatched if it is ready to be dispatched and no sources 
+ * at a higher (numerically smaller) priority are ready to be dispatched.
  **/
 void
 g_source_set_priority (GSource  *source,
@@ -1846,6 +1847,7 @@ gboolean
 g_main_context_prepare (GMainContext *context,
 			gint         *priority)
 {
+  gint i;
   gint n_ready = 0;
   gint current_priority = G_MAXINT;
   GSource *source;
@@ -1889,6 +1891,12 @@ g_main_context_prepare (GMainContext *context,
 #endif
 
   /* If recursing, clear list of pending dispatches */
+
+  for (i = 0; i < context->pending_dispatches->len; i++)
+    {
+      if (context->pending_dispatches->pdata[i])
+	SOURCE_UNREF ((GSource *)context->pending_dispatches->pdata[i], context);
+    }
   g_ptr_array_set_size (context->pending_dispatches, 0);
   
   /* Prepare all sources */
@@ -2121,6 +2129,11 @@ g_main_context_check (GMainContext *context,
 	  g_ptr_array_add (context->pending_dispatches, source);
 
 	  n_ready++;
+
+          /* never dispatch sources with less priority than the first
+           * one we choose to dispatch
+           */
+          max_priority = source->priority;
 	}
 
     next:
@@ -2295,7 +2308,7 @@ g_main_context_iteration (GMainContext *context, gboolean may_block)
  * g_main_loop_new:
  * @context: a #GMainContext  (if %NULL, the default context will be used).
  * @is_running: set to %TRUE to indicate that the loop is running. This
- * is not very important since calling g_main_run() will set this to
+ * is not very important since calling g_main_loop_run() will set this to
  * %TRUE anyway.
  * 
  * Creates a new #GMainLoop structure.
@@ -2380,7 +2393,7 @@ g_main_loop_unref (GMainLoop *loop)
  * g_main_loop_run:
  * @loop: a #GMainLoop
  * 
- * Runs a main loop until g_main_quit() is called on the loop.
+ * Runs a main loop until g_main_loop_quit() is called on the loop.
  * If this is called for the thread of the loop's #GMainContext,
  * it will process events from the loop, otherwise it will
  * simply wait.
@@ -2401,7 +2414,7 @@ g_main_loop_run (GMainLoop *loop)
       /* Another thread owns this context */
       if (!g_thread_supported ())
 	{
-	  g_warning ("g_main_loop_run() was called from second thread but"
+	  g_warning ("g_main_loop_run() was called from second thread but "
 		     "g_thread_init() was never called.");
 	  return;
 	}
@@ -2438,8 +2451,8 @@ g_main_loop_run (GMainLoop *loop)
 
   if (loop->context->in_check_or_prepare)
     {
-      g_warning ("g_main_run(): called recursively from within a source's check() or "
-		 "prepare() member, iteration not possible.");
+      g_warning ("g_main_loop_run(): called recursively from within a source's "
+		 "check() or prepare() member, iteration not possible.");
       return;
     }
 
@@ -2486,7 +2499,7 @@ g_main_loop_quit (GMainLoop *loop)
  * g_main_loop_is_running:
  * @loop: a #GMainLoop.
  * 
- * Checks to see if the main loop is currently being run via g_main_run().
+ * Checks to see if the main loop is currently being run via g_main_loop_run().
  * 
  * Return value: %TRUE if the mainloop is currently being run.
  **/
